pub struct SearchDocument {
pub id: String,
pub title: Option<String>,
pub body: String,
pub metadata: BTreeMap<String, String>,
pub source: Option<TextSourceRef>,
pub provenance: Vec<TextProvenance>,
pub annotations: Vec<TextAnnotationSpan>,
}Expand description
Data type for search document.
Fields
id: StringIdentifier for this value.
title: Option<String>The title value.
body: StringThe body value.
metadata: BTreeMap<String, String>Metadata associated with this value.
source: Option<TextSourceRef>Optional rich source reference.
provenance: Vec<TextProvenance>Provenance records for this document.
annotations: Vec<TextAnnotationSpan>Annotation spans associated with this document.
Implementations
Sourceimpl SearchDocument
impl SearchDocument
Sourcepub fn from_text_document(document: &TextDocument<'_>) -> Self
pub fn from_text_document(document: &TextDocument<'_>) -> Self
Builds this value from text document.
Sourcepub fn from_text_document_contract(document: &TextDocumentContract) -> Self
pub fn from_text_document_contract(document: &TextDocumentContract) -> Self
Builds this value from a portable text document contract.
Sourcepub fn from_text_segment_contract(segment: &TextSegmentContract) -> Self
pub fn from_text_segment_contract(segment: &TextSegmentContract) -> Self
Builds this value from a portable text segment contract.
Sourcepub fn from_text_corpus_document(document: &TextCorpusDocument) -> Self
pub fn from_text_corpus_document(document: &TextCorpusDocument) -> Self
Builds this value from a lexical corpus document without losing rich metadata.
Sourcepub fn from_text_corpus(corpus: &TextCorpus) -> Vec<Self>
pub fn from_text_corpus(corpus: &TextCorpus) -> Vec<Self>
Builds retrieval documents from a lexical corpus.